@@ -100,6 +100,9 @@ _server_queue_work_data(gearman_server_job_st *server_job,
  * Public definitions
  */
 
+#if __GNUC__ >= 7
+  #pragma GCC diagnostic warning "-Wimplicit-fallthrough"
+#endif
 gearmand_error_t gearman_server_run_command(gearman_server_con_st *server_con,
                                             gearmand_packet_st *packet)
 {
@@ -141,6 +144,7 @@ gearmand_error_t gearman_server_run_command(gearman_server_con_st *server_con,
     {
       return GEARMAND_MEMORY_ALLOCATION_FAILURE;
     }
+    /* fall-thru */
 
   case GEARMAN_COMMAND_SUBMIT_REDUCE_JOB_BACKGROUND:
     {
@@ -807,15 +811,16 @@ gearmand_error_t gearman_server_run_command(gearman_server_con_st *server_con,
       gearman_server_job_st *server_job= gearman_server_job_get(Server,
                                                                 (char *)(packet->arg[0]), (size_t)strlen(packet->arg[0]),
                                                                 server_con);
-      gearmand_log_debug(GEARMAN_DEFAULT_LOG_PARAM,
-                         "Exception being sent from: %.*s(%lu)",
-                         server_job->function->function_name_size, server_job->function->function_name, server_job->function->function_name_size);
       if (server_job == NULL)
       {
         return _server_error_packet(GEARMAN_DEFAULT_LOG_PARAM, server_con, GEARMAN_JOB_NOT_FOUND, 
                                     gearman_literal_param("An exception was received for a job that does not exist"));
       }
 
+      gearmand_log_debug(GEARMAN_DEFAULT_LOG_PARAM,
+                         "Exception being sent for handle: %.*s",
+                         (size_t)strlen(server_job->job_handle), server_job->job_handle);
+
       /* Queue the exception packet for all clients. */
       ret= _server_queue_work_data(server_job, packet, GEARMAN_COMMAND_WORK_EXCEPTION);
       if (gearmand_failed(ret))
