@@ -798,7 +798,7 @@ static test_return_t add_servers_test(void *)
   if (libtest::check_dns())
   {
     ASSERT_EQ(GEARMAN_GETADDRINFO,
-                 gearman_client_add_servers(&client, "exist.gearman.info:7003,does_not_exist.gearman.info:12345"));
+                 gearman_client_add_servers(&client, "www.google.com:7003,does_not_exist.google.com:12345"));
   }
 
   return TEST_SUCCESS;
